@@ -58,7 +58,7 @@ class CreateData(db.DataBase):
                 break
         return Flag
 
-    def create_data(self, interval: int, overall: int, mode: int) -> tuple[list, list, int, int]:
+    def create_data(self, interval: int, overall: int, mode: int) -> tuple[list, list, list, float, float]:
         """Create data for create_graph bar"""
 
         if interval == 1:
@@ -281,7 +281,6 @@ class CreateData(db.DataBase):
     def _legend_text(self, format_data: list, interval: int, mode: int, overall: int, overall_dif: list) -> tuple[list, float, float]:
         """Creates legend text for graph"""
 
-        maxval, minval = 0, 0
         legend_list = []
         average = []
 
@@ -291,8 +290,7 @@ class CreateData(db.DataBase):
             else:
                 average.append(self._average(format_data[index], interval))
 
-            if overall == 2:
-                maxval, best_period, minval, worst_period = self._max_min_value(format_data, interval, mode)
+            maxval, best_period, minval, worst_period = self._max_min_value(format_data, interval, mode)
 
             if interval == 3:
                 legend = f"{datetime.date(int(period[:4]), int(period[5:7]), 1).strftime('%B %Y')}, " \
@@ -325,3 +323,9 @@ class CreateData(db.DataBase):
             return f"\n({str(round(((second - first) / first) * 100, 2))}% {lg.compare_to_first_period_lang[self.LANGUAGE]})"
         else:
             return ''
+
+    def _color_schema(self, cm, length):
+        if length <= 8:
+            return [cm.tab10(i) for i in range(length + 2)]
+        else:
+            return [cm.tab20(i) for i in range(length + 2)]
